#########################################
Duration Representation Functionality
#########################################

.. |br| raw:: html

   <br />

Descriptions of the basic functions are given below.

**Function descriptions:**

.. automodule:: durationRepresentation
   :members:
   :member-order: bysource
